
class ListElement {
	int value;
	ListElement next;

	ListElement(int v, ListElement n) {
		value = v;
		next = n;
	}
}

class LinkedList {

	ListElement first;

	LinkedList() {
		first = null;
	}

	int size() {
		int result = 0;
		ListElement elem = first;
		while (elem != null) {
			result++;
			elem = elem.next;
		}
		return result;
	}

	void add(int value) {
		if (first == null) {
			first = new ListElement(value, null);
		} else {
			ListElement elem = first;
			while (elem.next != null) {
				elem = elem.next;
			}
			elem.next = new ListElement(value, null);
		}
	}

	void insert(int index, int value) { // without index check
		if (index == 0) {
			prepend(value);
		} else {
			ListElement elem = first;
			for (int i = 0; i < index - 1; i++) {
				elem = elem.next;
			}
			elem.next = new ListElement(value, elem.next);
		}
	}

	void prepend(int value) {
		first = new ListElement(value, first);
	}

	int get(int index) { // without index check
		ListElement elem = first;
		for (int i = 0; i < index; i++) {
			elem = elem.next;
		}
		return elem.value;
	}

	void remove(int value) {
		ListElement before = null;
		ListElement help = this.first;
		while (help != null) {
			if (help.value == value) {
				if (before != null) {
					before.next = help.next;
				} else { // Element == first
					this.first = help.next;
				}
			} else {
				before = help;
			}
			help = help.next;
		}
	}

	int removeAtIndex(int index) { // without index check
		int result = get(index);
		if (index == 0) {
			first = first.next;
		} else {
			ListElement elem = first;
			for (int i = 0; i < index-1; i++) {
				elem = elem.next;
			}
			elem.next = elem.next.next;
		}
		return result;
	}

	void clear() {
		first = null;
	}

	boolean contains(int value) {
		ListElement elem = first;
		while (elem != null) {
			if (elem.value == value) {
				return true;
			}
			elem = elem.next;
		}
		return false;
	}

	boolean isEmpty() {
		return first == null;
	}

	void set(int index, int value) { // without index check
		ListElement elem = first;
		for (int i = 0; i < index; i++) {
			elem = elem.next;
		}
		elem.value = value;
	}

	LinkedList subList(int fromIndex, int toIndex) { // without index check
		LinkedList result = new LinkedList();
		for (int i = fromIndex; i < toIndex; i++) { // ok, but slow
			result.add(this.get(i));
		}
		return result;
	}

	// Testprogramm
	public static void main(String[] args) {
		LinkedList list = new LinkedList();
		for (int i = 0; i < 10; i++) {
			list.add(i);
			list.add(i);
		}
		list.remove(5);
		list.remove(9);
		list.remove(0);
		for (int i = 10; i < 20; i++) {
			list.add(i);
		}
		list.insert(1, 77);
		for (int i = 0; i < list.size(); i++) {
			System.out.println(list.get(i));
		}
	}
}
